Struct scopegraphs::completeness::FutureCompleteness
source · pub struct FutureCompleteness<LABEL> { /* private fields */ }Expand description
A completeness strategy that makes queries return a Future
in case one of the scopes that the query runs over was not yet closed.
The future resolves once all such scopes are closed.
Using FutureCompleteness, you can somewhat delegate the task of scheduling
typechecking to one of rust’s executors, be it tokio
or futures::block_on.
Extends, and contains an instance of, ExplicitClose.