Struct scopegraphs::resolve::Query
source · pub struct Query<'storage, 'sg, 'rslv, LABEL, DATA, CMPL, PWF, DWF, LO, DEq> { /* private fields */ }Expand description
A query over a scope graph. Read more here
Implementations
sourceimpl<'sg, 'storage, 'rslv, LABEL, DATA, CMPL, PWF, DWF, LO, DEq> Query<'sg, 'storage, 'rslv, LABEL, DATA, CMPL, PWF, DWF, LO, DEq>
impl<'sg, 'storage, 'rslv, LABEL, DATA, CMPL, PWF, DWF, LO, DEq> Query<'sg, 'storage, 'rslv, LABEL, DATA, CMPL, PWF, DWF, LO, DEq>
sourcepub fn with_path_wellformedness<NPWF>(
self,
new_path_wellformedness: NPWF
) -> Query<'sg, 'storage, 'rslv, LABEL, DATA, CMPL, NPWF, DWF, LO, DEq>where
NPWF: for<'a> RegexMatcher<&'a LABEL> + 'rslv,
pub fn with_path_wellformedness<NPWF>(
self,
new_path_wellformedness: NPWF
) -> Query<'sg, 'storage, 'rslv, LABEL, DATA, CMPL, NPWF, DWF, LO, DEq>where
NPWF: for<'a> RegexMatcher<&'a LABEL> + 'rslv,
Add a path well-formedness to this query.
A path well-formedness can be specified using a regular expression.
Often you want to use query_regex! here.
#[derive(Label)]
pub enum Lbl {
Lexical,
Definition
}
use Lbl::*;
scopegraph.query()
.with_path_wellformedness(query_regex!(Lbl: Lexical* Definition));
sourcepub fn with_data_wellformedness<NDWF>(
self,
new_data_wellformedness: NDWF
) -> Query<'sg, 'storage, 'rslv, LABEL, DATA, CMPL, PWF, NDWF, LO, DEq>where
NDWF: DataWellformedness<DATA> + 'rslv,
pub fn with_data_wellformedness<NDWF>(
self,
new_data_wellformedness: NDWF
) -> Query<'sg, 'storage, 'rslv, LABEL, DATA, CMPL, PWF, NDWF, LO, DEq>where
NDWF: DataWellformedness<DATA> + 'rslv,
Add a data well-formedness to this query.
A data well-formedness must implement DataWellformedness.
Defaults to DefaultDataWellformedness, considering all data to be well-formed.
With a data well-formedness you can specify what data a scope must have to be a valid target for this query.
use scopegraphs::resolve::DataWellformedness;
struct MyData {
is_good: bool
}
struct MyDataWellformedness;
impl DataWellformedness<MyData> for MyDataWellformedness {
fn data_wf(&self, data: &MyData) -> bool {
data.is_good
}
}
scopegraph.query()
.with_data_wellformedness(MyDataWellformedness);
A data-wellformedness can be a lambda that takes a reference to DATA and returns a boolean.
use scopegraphs::resolve::DataWellformedness;
struct MyData {
is_good: bool
}
scopegraph.query()
.with_data_wellformedness(|data: &MyData| data.is_good);
sourcepub fn with_label_order<NLO>(
self,
new_label_order: NLO
) -> Query<'sg, 'storage, 'rslv, LABEL, DATA, CMPL, PWF, DWF, NLO, DEq>where
NLO: LabelOrder<LABEL> + 'rslv,
pub fn with_label_order<NLO>(
self,
new_label_order: NLO
) -> Query<'sg, 'storage, 'rslv, LABEL, DATA, CMPL, PWF, DWF, NLO, DEq>where
NLO: LabelOrder<LABEL> + 'rslv,
Add a label order to this query.
A label order must implement LabelOrder.
Defaults to DefaultLabelOrder, considering all labels of equal importance.
With a label order, you can specify which labels are “more important” in a query.
Specify label orders using the label_order! macro.
TODO: lower is better? from Lace.
use scopegraphs_macros::label_order;
#[derive(Label, Copy, Clone)]
pub enum Lbl {
Lexical,
Definition
}
use Lbl::*;
scopegraph.query()
.with_label_order(label_order!(Lbl: Lexical < Definition));sourcepub fn with_data_equivalence<NDEq>(
self,
new_data_equivalence: NDEq
) -> Query<'sg, 'storage, 'rslv, LABEL, DATA, CMPL, PWF, DWF, LO, NDEq>where
NDEq: DataEquivalence<DATA> + 'rslv,
pub fn with_data_equivalence<NDEq>(
self,
new_data_equivalence: NDEq
) -> Query<'sg, 'storage, 'rslv, LABEL, DATA, CMPL, PWF, DWF, LO, NDEq>where
NDEq: DataEquivalence<DATA> + 'rslv,
Add a data equivalence to this query.
A data equivalence must implement DataEquivalence.
TODO: example (@aron?)